==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorTokenAllOfVerify.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserFactorTokenVerifyRSA;
import com.okta.sdk.resource.model.UserFactorTokenVerifySymantec;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenAllOfVerify
 */
@JsonPropertyOrder({ UserFactorTokenAllOfVerify.JSON_PROPERTY_PASS_CODE,
        UserFactorTokenAllOfVerify.JSON_PROPERTY_NEXT_PASS_CODE })
@JsonTypeName("UserFactorToken_allOf_verify")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorTokenAllOfVerify implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PASS_CODE = "passCode";
    private String passCode;

    public static final String JSON_PROPERTY_NEXT_PASS_CODE = "nextPassCode";
    private Integer nextPassCode;

    public UserFactorTokenAllOfVerify() {
    }

    public UserFactorTokenAllOfVerify passCode(String passCode) {

        this.passCode = passCode;
        return this;
    }

    /**
     * OTP for the current time window
     *
     * @return passCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "5275875498", value = "OTP for the current time window")
    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPassCode() {
        return passCode;
    }

    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPassCode(String passCode) {
        this.passCode = passCode;
    }

    public UserFactorTokenAllOfVerify nextPassCode(Integer nextPassCode) {

        this.nextPassCode = nextPassCode;
        return this;
    }

    /**
     * OTP for the next time window
     *
     * @return nextPassCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "3956685498", value = "OTP for the next time window")
    @JsonProperty(JSON_PROPERTY_NEXT_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getNextPassCode() {
        return nextPassCode;
    }

    @JsonProperty(JSON_PROPERTY_NEXT_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNextPassCode(Integer nextPassCode) {
        this.nextPassCode = nextPassCode;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenAllOfVerify userFactorTokenAllOfVerify = (UserFactorTokenAllOfVerify) o;
        return Objects.equals(this.passCode, userFactorTokenAllOfVerify.passCode)
                && Objects.equals(this.nextPassCode, userFactorTokenAllOfVerify.nextPassCode);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(passCode, nextPassCode);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenAllOfVerify {\n");
        sb.append("    passCode: ").append(toIndentedString(passCode)).append("\n");
        sb.append("    nextPassCode: ").append(toIndentedString(nextPassCode)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorTokenAllOfVerify.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserFactorTokenVerifyRSA;
import com.okta.sdk.resource.model.UserFactorTokenVerifySymantec;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenAllOfVerify
 */
@JsonPropertyOrder({ UserFactorTokenAllOfVerify.JSON_PROPERTY_PASS_CODE,
        UserFactorTokenAllOfVerify.JSON_PROPERTY_NEXT_PASS_CODE })
@JsonTypeName("UserFactorToken_allOf_verify")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorTokenAllOfVerify implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PASS_CODE = "passCode";
    private String passCode;

    public static final String JSON_PROPERTY_NEXT_PASS_CODE = "nextPassCode";
    private Integer nextPassCode;

    public UserFactorTokenAllOfVerify() {
    }

    public UserFactorTokenAllOfVerify passCode(String passCode) {

        this.passCode = passCode;
        return this;
    }

    /**
     * OTP for the current time window
     *
     * @return passCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "5275875498", value = "OTP for the current time window")
    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPassCode() {
        return passCode;
    }

    @JsonProperty(JSON_PROPERTY_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPassCode(String passCode) {
        this.passCode = passCode;
    }

    public UserFactorTokenAllOfVerify nextPassCode(Integer nextPassCode) {

        this.nextPassCode = nextPassCode;
        return this;
    }

    /**
     * OTP for the next time window
     *
     * @return nextPassCode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "3956685498", value = "OTP for the next time window")
    @JsonProperty(JSON_PROPERTY_NEXT_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getNextPassCode() {
        return nextPassCode;
    }

    @JsonProperty(JSON_PROPERTY_NEXT_PASS_CODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNextPassCode(Integer nextPassCode) {
        this.nextPassCode = nextPassCode;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenAllOfVerify userFactorTokenAllOfVerify = (UserFactorTokenAllOfVerify) o;
        return Objects.equals(this.passCode, userFactorTokenAllOfVerify.passCode)
                && Objects.equals(this.nextPassCode, userFactorTokenAllOfVerify.nextPassCode);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(passCode, nextPassCode);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenAllOfVerify {\n");
        sb.append("    passCode: ").append(toIndentedString(passCode)).append("\n");
        sb.append("    nextPassCode: ").append(toIndentedString(nextPassCode)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
